Imports System
Imports System.Drawing
Imports System.Collections
Imports System.ComponentModel
Imports System.Windows.Forms
Imports CADImport
Imports CADImport.FaceModule
Imports CADImport.CADImportForms
''' <summary>
''' Represents a form in which the properties of the text are set 
''' before adding it to the current CAD image.
''' </summary>
Public Class AddTextForm
    Inherits Form
    ' Events
    Public Event ResizeImageEvent As CADImportEventHandler

    ' Methods
    ''' <summary>
    ''' Initializes a new instance of the <see cref="!:AddEntityDemoApplication.AddTextForm">AddTextForm</see> class.
    ''' </summary>
    Public Sub New()
        Me.InitializeComponent()
        Me.setColorDlg = New ColorDialog
        Me.cbHeights.SelectedIndex = 0
        Me.tbColor.Enabled = False
        MyBase.StartPosition = FormStartPosition.CenterScreen
    End Sub

    Private Sub btnCancel_Click(ByVal sender As Object, ByVal e As EventArgs)
        MyBase.DialogResult = DialogResult.Cancel
        MyBase.Close()
    End Sub

    Private Sub btnOK_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cText = New CADText
        If (Me.setColorDlg.Color.Equals(Color.Black)) Then
            Me.cText.Color = CADConst.clNone
        Else
            Me.cText.Color = Me.setColorDlg.Color
        End If
        Try
            Me.cText.Point = New DPoint(Convert.ToDouble(Me.tbX.Text), Convert.ToDouble(Me.tbY.Text), Convert.ToDouble(Me.tbZ.Text))
            Me.cText.Height = Convert.ToInt16(Me.cbHeights.Text)
            Me.cText.Rotation = Convert.ToInt32(Me.tbRotation.Text)
            Me.cText.Text = Me.tbText.Text
            Me.cadImage.Converter.GetSection(ConvSection.Entities).AddEntity(Me.cText)
            Me.cadImage.Converter.OnCreate(Me.cText)
            Me.cadImage.Converter.Loads(Me.cText)
            Me.OnResizeImage()
        Catch exception As FormatException
            MessageBox.Show(exception.Message, ApplicationConstants.appnamestr, MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
        End Try
        MyBase.DialogResult = DialogResult.OK
        MyBase.Close()
    End Sub

    Private Sub btnPickColor_Click(ByVal sender As Object, ByVal e As EventArgs)
        If (Me.setColorDlg.ShowDialog = DialogResult.OK) Then
            Me.tbColor.BackColor = Me.setColorDlg.Color
        End If
    End Sub

    ''' <summary>
    ''' Cleans up any resources being used.
    ''' </summary>
    ''' <param name="disposing">A value indicating if both managed and unmanaged resources have to be released (<b>true</b>) or only unmanaged (<b>false</b>). 
    ''' </param>
    Protected Overloads Sub Dispose(ByVal disposing As Boolean)
        If (disposing AndAlso (Not Me.components Is Nothing)) Then
            Me.components.Dispose()
        End If
        MyBase.Dispose(disposing)
    End Sub

#Region " Windows Form Designer generated code "
    ''' <summary>
    ''' Required method for Designer support - do not modify
    ''' the contents of this method with the code editor.
    ''' </summary>
    Private Sub InitializeComponent()
        Me.btnPickColor = New Button
        Me.tbColor = New TextBox
        Me.lbColor = New Label
        Me.RAlab = New Label
        Me.line5 = New Label
        Me.line4 = New Label
        Me.line3 = New Label
        Me.line2 = New Label
        Me.line1 = New Label
        Me.lbY = New Label
        Me.lbZ = New Label
        Me.lbX = New Label
        Me.tbZ = New TextBox
        Me.tbY = New TextBox
        Me.tbX = New TextBox
        Me.vertLine2 = New Label
        Me.vertLine1 = New Label
        Me.lbFirst = New Label
        Me.btCancel = New Button
        Me.btOK = New Button
        Me.tbRotation = New TextBox
        Me.cbHeights = New ComboBox
        Me.lWlab = New Label
        Me.label1 = New Label
        Me.tbText = New TextBox
        Me.label2 = New Label
        MyBase.SuspendLayout()
        Me.btnPickColor.FlatStyle = FlatStyle.System
        Me.btnPickColor.Location = New Point(&H88, 8)
        Me.btnPickColor.Name = "btnPickColor"
        Me.btnPickColor.Size = New Size(&H48, &H19)
        Me.btnPickColor.TabIndex = 10
        Me.btnPickColor.Text = "Pick a color"
        AddHandler Me.btnPickColor.Click, New System.EventHandler(AddressOf Me.btnPickColor_Click)
        Me.tbColor.BackColor = Color.Black
        Me.tbColor.Location = New Point(&H38, 8)
        Me.tbColor.Multiline = True
        Me.tbColor.Name = "tbColor"
        Me.tbColor.Size = New Size(&H38, &H17)
        Me.tbColor.TabIndex = 9
        Me.tbColor.Text = ""
        Me.lbColor.FlatStyle = FlatStyle.System
        Me.lbColor.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbColor.Location = New Point(8, 8)
        Me.lbColor.Name = "lbColor"
        Me.lbColor.Size = New Size(&H30, &H17)
        Me.lbColor.TabIndex = 8
        Me.lbColor.Text = "Color :"
        Me.RAlab.FlatStyle = FlatStyle.System
        Me.RAlab.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.RAlab.Location = New Point(8, &HA8)
        Me.RAlab.Name = "RAlab"
        Me.RAlab.Size = New Size(&H68, 20)
        Me.RAlab.TabIndex = &H1F
        Me.RAlab.Text = "Rotation angle :"
        Me.line5.BackColor = Color.Black
        Me.line5.Location = New Point(10, 160)
        Me.line5.Name = "line5"
        Me.line5.Size = New Size(&HC6, 1)
        Me.line5.TabIndex = &H25
        Me.line4.BackColor = Color.Black
        Me.line4.Location = New Point(10, &H80)
        Me.line4.Name = "line4"
        Me.line4.Size = New Size(&HC6, 1)
        Me.line4.TabIndex = &H24
        Me.line3.BackColor = Color.Black
        Me.line3.Location = New Point(10, &H60)
        Me.line3.Name = "line3"
        Me.line3.Size = New Size(&HC6, 1)
        Me.line3.TabIndex = &H23
        Me.line2.BackColor = Color.Black
        Me.line2.Location = New Point(10, &H40)
        Me.line2.Name = "line2"
        Me.line2.Size = New Size(&HC6, 1)
        Me.line2.TabIndex = &H22
        Me.line1.BackColor = Color.Black
        Me.line1.Location = New Point(10, 40)
        Me.line1.Name = "line1"
        Me.line1.Size = New Size(&HC6, 1)
        Me.line1.TabIndex = &H21
        Me.lbY.FlatStyle = FlatStyle.System
        Me.lbY.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbY.Location = New Point(10, &H68)
        Me.lbY.Name = "lbY"
        Me.lbY.Size = New Size(&H62, 20)
        Me.lbY.TabIndex = &H27
        Me.lbY.Text = "Y coordinate :"
        Me.lbY.TextAlign = ContentAlignment.MiddleCenter
        Me.lbZ.FlatStyle = FlatStyle.System
        Me.lbZ.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbZ.Location = New Point(10, &H88)
        Me.lbZ.Name = "lbZ"
        Me.lbZ.Size = New Size(&H62, 20)
        Me.lbZ.TabIndex = 40
        Me.lbZ.Text = "Z coordinate :"
        Me.lbZ.TextAlign = ContentAlignment.MiddleCenter
        Me.lbX.FlatStyle = FlatStyle.System
        Me.lbX.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbX.Location = New Point(10, &H48)
        Me.lbX.Name = "lbX"
        Me.lbX.Size = New Size(&H62, 20)
        Me.lbX.TabIndex = &H26
        Me.lbX.Text = "X coordinate :"
        Me.lbX.TextAlign = ContentAlignment.MiddleCenter
        Me.tbZ.Location = New Point(&H7A, &H88)
        Me.tbZ.Name = "tbZ"
        Me.tbZ.Size = New Size(&H4C, 20)
        Me.tbZ.TabIndex = &H2B
        Me.tbZ.Text = "0,0"
        Me.tbY.Location = New Point(&H7A, &H68)
        Me.tbY.Name = "tbY"
        Me.tbY.Size = New Size(&H4C, 20)
        Me.tbY.TabIndex = &H2A
        Me.tbY.Text = "0,0"
        Me.tbX.Location = New Point(&H7A, &H48)
        Me.tbX.Name = "tbX"
        Me.tbX.Size = New Size(&H4C, 20)
        Me.tbX.TabIndex = &H29
        Me.tbX.Text = "0,0"
        Me.vertLine2.BackColor = Color.Black
        Me.vertLine2.Location = New Point(&HCF, 40)
        Me.vertLine2.Name = "vertLine2"
        Me.vertLine2.Size = New Size(1, 120)
        Me.vertLine2.TabIndex = &H2D
        Me.vertLine1.BackColor = Color.Black
        Me.vertLine1.Location = New Point(&H6A, 40)
        Me.vertLine1.Name = "vertLine1"
        Me.vertLine1.Size = New Size(1, 120)
        Me.vertLine1.TabIndex = &H2C
        Me.lbFirst.FlatStyle = FlatStyle.System
        Me.lbFirst.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbFirst.Location = New Point(&H7A, &H2D)
        Me.lbFirst.Name = "lbFirst"
        Me.lbFirst.Size = New Size(&H44, &H10)
        Me.lbFirst.TabIndex = &H2E
        Me.lbFirst.Text = "Start point"
        Me.btCancel.FlatStyle = FlatStyle.System
        Me.btCancel.Location = New Point(&H85, 320)
        Me.btCancel.Name = "btCancel"
        Me.btCancel.Size = New Size(&H4B, &H19)
        Me.btCancel.TabIndex = &H30
        Me.btCancel.Text = "Cancel"
        AddHandler Me.btCancel.Click, New System.EventHandler(AddressOf Me.btnCancel_Click)
        Me.btOK.FlatStyle = FlatStyle.System
        Me.btOK.Location = New Point(&H30, 320)
        Me.btOK.Name = "btOK"
        Me.btOK.Size = New Size(&H4B, &H19)
        Me.btOK.TabIndex = &H2F
        Me.btOK.Text = "OK"
        AddHandler Me.btOK.Click, New System.EventHandler(AddressOf Me.btnOK_Click)
        Me.tbRotation.Location = New Point(120, &HA8)
        Me.tbRotation.Name = "tbRotation"
        Me.tbRotation.Size = New Size(&H4C, 20)
        Me.tbRotation.TabIndex = &H31
        Me.tbRotation.Text = "0"
        Me.cbHeights.DropDownStyle = ComboBoxStyle.DropDownList
        Me.cbHeights.Items.AddRange(New Object() {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50", "51", "52", "53", "54", "55", "56", "57", "58", "59", "60", "61", "62", "63", "64", "65", "66", "67", "68", "69", "70", "71", "72", "73", "74", "75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", "86", "87", "88", "89", "90", "91", "92", "93", "94", "95", "96", "97", "98", "99", "100"})
        Me.cbHeights.Location = New Point(120, &HC0)
        Me.cbHeights.Name = "cbHeights"
        Me.cbHeights.Size = New Size(&H4C, &H15)
        Me.cbHeights.TabIndex = &H33
        Me.lWlab.FlatStyle = FlatStyle.System
        Me.lWlab.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lWlab.Location = New Point(8, &HC0)
        Me.lWlab.Name = "lWlab"
        Me.lWlab.Size = New Size(&H68, 20)
        Me.lWlab.TabIndex = 50
        Me.lWlab.Text = "Text height :"
        Me.label1.FlatStyle = FlatStyle.System
        Me.label1.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.label1.Location = New Point(8, &HD8)
        Me.label1.Name = "label1"
        Me.label1.TabIndex = &H34
        Me.label1.Text = "Text contents :"
        Me.tbText.Location = New Point(8, 240)
        Me.tbText.Multiline = True
        Me.tbText.Name = "tbText"
        Me.tbText.Size = New Size(200, &H48)
        Me.tbText.TabIndex = &H35
        Me.tbText.Text = ""
        Me.label2.BackColor = Color.Black
        Me.label2.Location = New Point(10, 40)
        Me.label2.Name = "label2"
        Me.label2.Size = New Size(1, 120)
        Me.label2.TabIndex = &H36
        Me.AutoScaleBaseSize = New Size(5, 13)
        MyBase.ClientSize = New Size(&HD8, &H160)
        MyBase.Controls.Add(Me.label2)
        MyBase.Controls.Add(Me.tbText)
        MyBase.Controls.Add(Me.label1)
        MyBase.Controls.Add(Me.cbHeights)
        MyBase.Controls.Add(Me.lWlab)
        MyBase.Controls.Add(Me.tbRotation)
        MyBase.Controls.Add(Me.btCancel)
        MyBase.Controls.Add(Me.btOK)
        MyBase.Controls.Add(Me.lbFirst)
        MyBase.Controls.Add(Me.vertLine2)
        MyBase.Controls.Add(Me.vertLine1)
        MyBase.Controls.Add(Me.tbZ)
        MyBase.Controls.Add(Me.tbY)
        MyBase.Controls.Add(Me.tbX)
        MyBase.Controls.Add(Me.lbY)
        MyBase.Controls.Add(Me.lbZ)
        MyBase.Controls.Add(Me.lbX)
        MyBase.Controls.Add(Me.line5)
        MyBase.Controls.Add(Me.line4)
        MyBase.Controls.Add(Me.line3)
        MyBase.Controls.Add(Me.line2)
        MyBase.Controls.Add(Me.line1)
        MyBase.Controls.Add(Me.RAlab)
        MyBase.Controls.Add(Me.btnPickColor)
        MyBase.Controls.Add(Me.tbColor)
        MyBase.Controls.Add(Me.lbColor)
        MyBase.FormBorderStyle = FormBorderStyle.FixedSingle
        MyBase.MaximizeBox = False
        MyBase.Name = "AddTextForm"
        MyBase.StartPosition = FormStartPosition.CenterParent
        Me.Text = "Add Text"
        MyBase.ResumeLayout(False)
    End Sub
#End Region

    Public Sub OnResizeImage()
        'If (Not Me.ResizeImageEvent Is Nothing) Then
        RaiseEvent ResizeImageEvent()
        'End If
    End Sub


    ' Properties
    Public Property Image() As CADImage
        Get
            Return Me.cadImage
        End Get
        Set(ByVal value As CADImage)
            Me.cadImage = value
        End Set
    End Property


    ' Fields
    Private btCancel As Button
    Private btnPickColor As Button
    Private btOK As Button
    Private cadImage As CADImage
    Private cbHeights As ComboBox
    Private components As Container = Nothing
    Private cText As CADText
    Private label1 As Label
    Private label2 As Label
    Private lbColor As Label
    Private lbFirst As Label
    Private lbX As Label
    Private lbY As Label
    Private lbZ As Label
    Private line1 As Label
    Private line2 As Label
    Private line3 As Label
    Private line4 As Label
    Private line5 As Label
    Private lWlab As Label
    Private RAlab As Label
    Private setColorDlg As ColorDialog
    Private tbColor As TextBox
    Private tbRotation As TextBox
    Private tbText As TextBox
    Private tbX As TextBox
    Private tbY As TextBox
    Private tbZ As TextBox
    Private vertLine1 As Label
    Private vertLine2 As Label
End Class


